@@ -1,5 +1,5 @@
 #******************************************************************************
-# $Id: POP3Client.pm,v 2.14 2003/03/22 19:58:47 ssd Exp $
+# $Id: POP3Client.pm,v 2.15 2003/10/18 23:12:46 ssd Exp $
 #
 # Description:  POP3Client module - acts as interface to POP3 server
 # Author:       Sean Dowd <pop3client@dowds.net>
@@ -28,8 +28,8 @@ require Exporter;
 
 );
 
-my $ID =q( $Id: POP3Client.pm,v 2.14 2003/03/22 19:58:47 ssd Exp $ );
-$VERSION = substr q$Revision: 2.14 $, 10;
+my $ID =q( $Id: POP3Client.pm,v 2.15 2003/10/18 23:12:46 ssd Exp $ );
+$VERSION = substr q$Revision: 2.15 $, 10;
 
 
 # Preloaded methods go here.
@@ -229,6 +229,12 @@ sub Socket {
   $me->{'SOCKET'} = $socket;
 }
 
+sub AuthMode {
+  my $me = shift;
+  my $mode = shift;
+  return $me->{'AUTH_MODE'} unless $mode;
+  $me->{'AUTH_MODE'} = $mode;
+}
 
 #******************************************************************************
 #* set/query the USER
@@ -503,7 +509,8 @@ sub Login_CRAM_MD5
 
     my $hmac =
       Digest::HMAC_MD5::hmac_md5_hex(MIME::Base64::decode($1), $me->Pass());
-    $me->_sockprint(MIME::Base64::encode($me->User() . " $hmac", $me->EOL()));
+    (my $response = MIME::Base64::encode($me->User() . " $hmac")) =~ s/[\r\n]//g;
+    $me->_sockprint($response, $me->EOL());
 
     $line = $me->_sockread();
     chomp $line;
@@ -1360,7 +1367,10 @@ QUIT (invoking the Close method).  Can be reset with a Reset message.
 =item I<Connect>
 
 Start the connection to the POP3 server.  You can pass in the host and
-port.
+port.  Returns the number of messages in the mailbox, or -1 on a
+connection error.  The constructors return the value of Connect, so
+they will never return undef.  This will change in any version 3.x
+release, but never in a 2.x release.
 
 =item I<Close>
 
